@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -278,9 +277,16 @@ browser_location_ready_cb (GthBrowser    *browser,
 
 	if (! gth_test_chain_has_type_test (task->priv->test)) {
 		GthTest *general_filter;
+		GthTest *test_with_general_filter;
 
 		general_filter = gth_main_get_general_filter ();
-		gth_test_chain_add_test (task->priv->test, general_filter);
+		test_with_general_filter = gth_test_chain_new (GTH_MATCH_TYPE_ALL,
+							       general_filter,
+							       task->priv->test,
+							       NULL);
+
+		g_object_unref (task->priv->test);
+		task->priv->test = (GthTestChain *) test_with_general_filter;
 
 		g_object_unref (general_filter);
 	}
