@@ -196,7 +196,6 @@ struct _GthImageSelectorPrivate {
 	GthSelectorType  type;
 
 	GdkPixbuf       *pixbuf;
-	GdkPixbuf       *background;
 	GdkRectangle     pixbuf_area;
 
 	gboolean         use_ratio;
@@ -580,12 +579,33 @@ paint_background (GthImageSelector *self,
 {
 	gth_image_viewer_paint_region (self->priv->viewer,
 				       cr,
-				       self->priv->background,
+				       self->priv->pixbuf,
 				       self->priv->viewer->x_offset - self->priv->viewer->image_area.x,
 				       self->priv->viewer->y_offset - self->priv->viewer->image_area.y,
 				       &self->priv->viewer->image_area,
 				       event->region,
 				       GDK_INTERP_TILES);
+
+	/* make the background darker */
+	{
+		GdkRectangle *rects;
+		int           n_rects;
+		int           i;
+
+		gdk_cairo_rectangle (cr, &self->priv->viewer->image_area);
+		cairo_clip (cr);
+		cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.5);
+		gdk_region_get_rectangles (event->region, &rects, &n_rects);
+		for (i = 0; i < n_rects; i++) {
+			GdkRectangle paint_area;
+
+			if (gdk_rectangle_intersect (&self->priv->viewer->image_area, &rects[i], &paint_area))
+				cairo_rectangle (cr, paint_area.x, paint_area.y, paint_area.width, paint_area.height);
+		}
+		cairo_fill (cr);
+
+		g_free (rects);
+	}
 }
 
 
@@ -612,13 +632,11 @@ paint_selection (GthImageSelector *self,
 	cairo_save (cr);
 #if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 9, 2)
 	cairo_set_operator (cr, CAIRO_OPERATOR_DIFFERENCE);
-	cairo_set_source_rgb (cr, 0.0, 0.0, 0.0);
+	cairo_set_source_rgb (cr, 1.0, 1.0, 1.0);
 #else
 	cairo_set_source_rgb (cr, 1.0, 1.0, 1.0);
 #endif
 
-
-	gdk_cairo_region (cr, event->region);
 	gdk_cairo_rectangle (cr, &selection_area);
 	cairo_clip (cr);
 
@@ -663,8 +681,8 @@ paint_selection (GthImageSelector *self,
 	cairo_rectangle (cr,
 			 selection_area.x + 0.5,
 			 selection_area.y + 0.5,
-			 selection_area.width,
-			 selection_area.height);
+			 selection_area.width - 1,
+			 selection_area.height - 1);
 	cairo_stroke (cr);
 
 	cairo_restore (cr);
@@ -770,6 +788,7 @@ gth_image_selector_button_release (GthImageViewerTool *base,
 	update_cursor (self,
 		       event->x + self->priv->viewer->x_offset,
 		       event->y + self->priv->viewer->y_offset);
+	gtk_widget_queue_draw (GTK_WIDGET (self->priv->viewer));
 
 	return FALSE;
 }
@@ -942,6 +961,7 @@ gth_image_selector_button_press (GthImageViewerTool *base,
 		self->priv->viewer->pressed = TRUE;
 		self->priv->viewer->dragging = TRUE;
 		self->priv->drag_start_selection_area = self->priv->selection_area;
+		gtk_widget_queue_draw (GTK_WIDGET (self->priv->viewer));
 		retval = TRUE;
 	}
 
@@ -1277,9 +1297,6 @@ gth_image_selector_image_changed (GthImageViewerTool *base)
 	_g_object_unref (self->priv->pixbuf);
 	self->priv->pixbuf = gth_image_viewer_get_current_pixbuf (self->priv->viewer);
 
-	_g_object_unref (self->priv->background);
-	self->priv->background = NULL;
-
 	if (self->priv->pixbuf == NULL) {
 		self->priv->pixbuf_area.width = 0;
 		self->priv->pixbuf_area.height = 0;
@@ -1290,15 +1307,6 @@ gth_image_selector_image_changed (GthImageViewerTool *base)
 	self->priv->pixbuf_area.width = gdk_pixbuf_get_width (self->priv->pixbuf);
 	self->priv->pixbuf_area.height = gdk_pixbuf_get_height (self->priv->pixbuf);
 
-	self->priv->background = gdk_pixbuf_composite_color_simple (
-					self->priv->pixbuf,
-					gdk_pixbuf_get_width (self->priv->pixbuf),
-					gdk_pixbuf_get_height (self->priv->pixbuf),
-					GDK_INTERP_TILES,
-					128,
-					10,
-					0x00000000,
-					0x00000000);
 	init_selection (self);
 }
 
@@ -1337,9 +1345,7 @@ gth_image_selector_finalize (GObject *object)
 	g_return_if_fail (GTH_IS_IMAGE_SELECTOR (object));
 
 	self = (GthImageSelector *) object;
-
 	_g_object_unref (self->priv->pixbuf);
-	_g_object_unref (self->priv->background);
 
 	/* Chain up */
 	G_OBJECT_CLASS (parent_class)->finalize (object);
